==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v2/model/EventType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonValue;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

/** Type of the event. */
@JsonSerialize(using = EventType.EventTypeSerializer.class)
public class EventType {

  public static final EventType EVENT = new EventType("event");

  private static final Set<String> allowedValues = new HashSet<String>(Arrays.asList("event"));

  private String value;

  public boolean isValid() {
    return allowedValues.contains(this.value);
  }

  EventType(String value) {
    this.value = value;
  }

  public static class EventTypeSerializer extends StdSerializer<EventType> {
    public EventTypeSerializer(Class<EventType> t) {
      super(t);
    }

    public EventTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(EventType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonValue
  public String getValue() {
    return this.value;
  }

  public void setValue(String value) {
    this.value = value;
  }

  /** Return true if this EventType object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    return this.value.equals(((EventType) o).value);
  }

  @Override
  public int hashCode() {
    return Objects.hash(value);
  }

  @Override
  public String toString() {
    return String.valueOf(value);
  }

  @JsonCreator
  public static EventType fromValue(String value) {
    return new EventType(value);
  }
}

==> datadog-api-client-2.24.0-sources.jar: com/datadog/api/client/v2/model/EventType.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.datadog.api.client.ModelEnum;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;
import java.io.IOException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

/** Type of the event. */
@JsonSerialize(using = EventType.EventTypeSerializer.class)
public class EventType extends ModelEnum<String> {

  private static final Set<String> allowedValues = new HashSet<String>(Arrays.asList("event"));

  public static final EventType EVENT = new EventType("event");

  EventType(String value) {
    super(value, allowedValues);
  }

  public static class EventTypeSerializer extends StdSerializer<EventType> {
    public EventTypeSerializer(Class<EventType> t) {
      super(t);
    }

    public EventTypeSerializer() {
      this(null);
    }

    @Override
    public void serialize(EventType value, JsonGenerator jgen, SerializerProvider provider)
        throws IOException, JsonProcessingException {
      jgen.writeObject(value.value);
    }
  }

  @JsonCreator
  public static EventType fromValue(String value) {
    return new EventType(value);
  }
}
